Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Options ¶
type Options struct {
Database *gorm.DB
TablePrefix string
LoadSettings func(ctx context.Context, prefix string) (map[string]string, error)
QuerySubjects identity.QuerySubjectsFunc
Authorize identity.AuthorizeFunc
ResponseWriter contract.ResponseWriter
FileStorage contract.FileStorage
BusinessReadTools []contract.BusinessReadTool
BusinessActionTools []contract.BusinessActionTool
CustomerQuickActions []contract.CustomerQuickAction
PlatformAI contract.PlatformAIProvider
}
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
enums
command
|
|
|
generator
command
|
|
|
server
command
|
|
|
internal
|
|
|
ai/runtime/readtools
Package readtools executes deterministic, read-only graph tools through the shared Tool Registry boundary.
|
Package readtools executes deterministic, read-only graph tools through the shared Tool Registry boundary. |
|
ai/tooling
Package tooling provides the engine-independent tool governance boundary.
|
Package tooling provides the engine-independent tool governance boundary. |
Click to show internal directories.
Click to hide internal directories.